==> google-cloud-speech-2.9.3.tar.gz: google-cloud-speech-2.9.3/google/cloud/speech_v1p1beta1/services/adaptation/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
import packaging.version
import pkg_resources

import google.auth  # type: ignore
import google.api_core  # type: ignore
from google.api_core import exceptions as core_exceptions  # type: ignore
from google.api_core import gapic_v1  # type: ignore
from google.api_core import retry as retries  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.cloud.speech_v1p1beta1.types import cloud_speech_adaptation
from google.cloud.speech_v1p1beta1.types import resource
from google.protobuf import empty_pb2  # type: ignore

try:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
        gapic_version=pkg_resources.get_distribution("google-cloud-speech",).version,
    )
except pkg_resources.DistributionNotFound:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()

try:
    # google.auth.__version__ was added in 1.26.0
    _GOOGLE_AUTH_VERSION = google.auth.__version__
except AttributeError:
    try:  # try pkg_resources if it is available
        _GOOGLE_AUTH_VERSION = pkg_resources.get_distribution("google-auth").version
    except pkg_resources.DistributionNotFound:  # pragma: NO COVER
        _GOOGLE_AUTH_VERSION = None


class AdaptationTransport(abc.ABC):
    """Abstract transport class for Adaptation."""

    AUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)

    DEFAULT_HOST: str = "speech.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: ga_credentials.Credentials = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """
        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

        scopes_kwargs = self._get_scopes_kwargs(self._host, scopes)

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )

        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

    # TODO(busunkim): This method is in the base transport
    # to avoid duplicating code across the transport classes. These functions
    # should be deleted once the minimum required versions of google-auth is increased.

    # TODO: Remove this function once google-auth >= 1.25.0 is required
    @classmethod
    def _get_scopes_kwargs(
        cls, host: str, scopes: Optional[Sequence[str]]
    ) -> Dict[str, Optional[Sequence[str]]]:
        """Returns scopes kwargs to pass to google-auth methods depending on the google-auth version"""

        scopes_kwargs = {}

        if _GOOGLE_AUTH_VERSION and (
            packaging.version.parse(_GOOGLE_AUTH_VERSION)
            >= packaging.version.parse("1.25.0")
        ):
            scopes_kwargs = {"scopes": scopes, "default_scopes": cls.AUTH_SCOPES}
        else:
            scopes_kwargs = {"scopes": scopes or cls.AUTH_SCOPES}

        return scopes_kwargs

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.create_phrase_set: gapic_v1.method.wrap_method(
                self.create_phrase_set, default_timeout=None, client_info=client_info,
            ),
            self.get_phrase_set: gapic_v1.method.wrap_method(
                self.get_phrase_set, default_timeout=None, client_info=client_info,
            ),
            self.list_phrase_set: gapic_v1.method.wrap_method(
                self.list_phrase_set, default_timeout=None, client_info=client_info,
            ),
            self.update_phrase_set: gapic_v1.method.wrap_method(
                self.update_phrase_set, default_timeout=None, client_info=client_info,
            ),
            self.delete_phrase_set: gapic_v1.method.wrap_method(
                self.delete_phrase_set, default_timeout=None, client_info=client_info,
            ),
            self.create_custom_class: gapic_v1.method.wrap_method(
                self.create_custom_class, default_timeout=None, client_info=client_info,
            ),
            self.get_custom_class: gapic_v1.method.wrap_method(
                self.get_custom_class, default_timeout=None, client_info=client_info,
            ),
            self.list_custom_classes: gapic_v1.method.wrap_method(
                self.list_custom_classes, default_timeout=None, client_info=client_info,
            ),
            self.update_custom_class: gapic_v1.method.wrap_method(
                self.update_custom_class, default_timeout=None, client_info=client_info,
            ),
            self.delete_custom_class: gapic_v1.method.wrap_method(
                self.delete_custom_class, default_timeout=None, client_info=client_info,
            ),
        }

    @property
    def create_phrase_set(
        self,
    ) -> Callable[
        [cloud_speech_adaptation.CreatePhraseSetRequest],
        Union[resource.PhraseSet, Awaitable[resource.PhraseSet]],
    ]:
        raise NotImplementedError()

    @property
    def get_phrase_set(
        self,
    ) -> Callable[
        [cloud_speech_adaptation.GetPhraseSetRequest],
        Union[resource.PhraseSet, Awaitable[resource.PhraseSet]],
    ]:
        raise NotImplementedError()

    @property
    def list_phrase_set(
        self,
    ) -> Callable[
        [cloud_speech_adaptation.ListPhraseSetRequest],
        Union[
            cloud_speech_adaptation.ListPhraseSetResponse,
            Awaitable[cloud_speech_adaptation.ListPhraseSetResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def update_phrase_set(
        self,
    ) -> Callable[
        [cloud_speech_adaptation.UpdatePhraseSetRequest],
        Union[resource.PhraseSet, Awaitable[resource.PhraseSet]],
    ]:
        raise NotImplementedError()

    @property
    def delete_phrase_set(
        self,
    ) -> Callable[
        [cloud_speech_adaptation.DeletePhraseSetRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def create_custom_class(
        self,
    ) -> Callable[
        [cloud_speech_adaptation.CreateCustomClassRequest],
        Union[resource.CustomClass, Awaitable[resource.CustomClass]],
    ]:
        raise NotImplementedError()

    @property
    def get_custom_class(
        self,
    ) -> Callable[
        [cloud_speech_adaptation.GetCustomClassRequest],
        Union[resource.CustomClass, Awaitable[resource.CustomClass]],
    ]:
        raise NotImplementedError()

    @property
    def list_custom_classes(
        self,
    ) -> Callable[
        [cloud_speech_adaptation.ListCustomClassesRequest],
        Union[
            cloud_speech_adaptation.ListCustomClassesResponse,
            Awaitable[cloud_speech_adaptation.ListCustomClassesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def update_custom_class(
        self,
    ) -> Callable[
        [cloud_speech_adaptation.UpdateCustomClassRequest],
        Union[resource.CustomClass, Awaitable[resource.CustomClass]],
    ]:
        raise NotImplementedError()

    @property
    def delete_custom_class(
        self,
    ) -> Callable[
        [cloud_speech_adaptation.DeleteCustomClassRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()


__all__ = ("AdaptationTransport",)

==> google-cloud-speech-2.11.1.tar.gz: google-cloud-speech-2.11.1/google/cloud/speech_v1p1beta1/services/adaptation/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
import pkg_resources

import google.auth  # type: ignore
import google.api_core  # type: ignore
from google.api_core import exceptions as core_exceptions  # type: ignore
from google.api_core import gapic_v1  # type: ignore
from google.api_core import retry as retries  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.cloud.speech_v1p1beta1.types import cloud_speech_adaptation
from google.cloud.speech_v1p1beta1.types import resource
from google.protobuf import empty_pb2  # type: ignore

try:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
        gapic_version=pkg_resources.get_distribution("google-cloud-speech",).version,
    )
except pkg_resources.DistributionNotFound:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()


class AdaptationTransport(abc.ABC):
    """Abstract transport class for Adaptation."""

    AUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)

    DEFAULT_HOST: str = "speech.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: ga_credentials.Credentials = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """
        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )

        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.create_phrase_set: gapic_v1.method.wrap_method(
                self.create_phrase_set, default_timeout=None, client_info=client_info,
            ),
            self.get_phrase_set: gapic_v1.method.wrap_method(
                self.get_phrase_set, default_timeout=None, client_info=client_info,
            ),
            self.list_phrase_set: gapic_v1.method.wrap_method(
                self.list_phrase_set, default_timeout=None, client_info=client_info,
            ),
            self.update_phrase_set: gapic_v1.method.wrap_method(
                self.update_phrase_set, default_timeout=None, client_info=client_info,
            ),
            self.delete_phrase_set: gapic_v1.method.wrap_method(
                self.delete_phrase_set, default_timeout=None, client_info=client_info,
            ),
            self.create_custom_class: gapic_v1.method.wrap_method(
                self.create_custom_class, default_timeout=None, client_info=client_info,
            ),
            self.get_custom_class: gapic_v1.method.wrap_method(
                self.get_custom_class, default_timeout=None, client_info=client_info,
            ),
            self.list_custom_classes: gapic_v1.method.wrap_method(
                self.list_custom_classes, default_timeout=None, client_info=client_info,
            ),
            self.update_custom_class: gapic_v1.method.wrap_method(
                self.update_custom_class, default_timeout=None, client_info=client_info,
            ),
            self.delete_custom_class: gapic_v1.method.wrap_method(
                self.delete_custom_class, default_timeout=None, client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

       .. warning::
            Only call this method if the transport is NOT shared
            with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def create_phrase_set(
        self,
    ) -> Callable[
        [cloud_speech_adaptation.CreatePhraseSetRequest],
        Union[resource.PhraseSet, Awaitable[resource.PhraseSet]],
    ]:
        raise NotImplementedError()

    @property
    def get_phrase_set(
        self,
    ) -> Callable[
        [cloud_speech_adaptation.GetPhraseSetRequest],
        Union[resource.PhraseSet, Awaitable[resource.PhraseSet]],
    ]:
        raise NotImplementedError()

    @property
    def list_phrase_set(
        self,
    ) -> Callable[
        [cloud_speech_adaptation.ListPhraseSetRequest],
        Union[
            cloud_speech_adaptation.ListPhraseSetResponse,
            Awaitable[cloud_speech_adaptation.ListPhraseSetResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def update_phrase_set(
        self,
    ) -> Callable[
        [cloud_speech_adaptation.UpdatePhraseSetRequest],
        Union[resource.PhraseSet, Awaitable[resource.PhraseSet]],
    ]:
        raise NotImplementedError()

    @property
    def delete_phrase_set(
        self,
    ) -> Callable[
        [cloud_speech_adaptation.DeletePhraseSetRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def create_custom_class(
        self,
    ) -> Callable[
        [cloud_speech_adaptation.CreateCustomClassRequest],
        Union[resource.CustomClass, Awaitable[resource.CustomClass]],
    ]:
        raise NotImplementedError()

    @property
    def get_custom_class(
        self,
    ) -> Callable[
        [cloud_speech_adaptation.GetCustomClassRequest],
        Union[resource.CustomClass, Awaitable[resource.CustomClass]],
    ]:
        raise NotImplementedError()

    @property
    def list_custom_classes(
        self,
    ) -> Callable[
        [cloud_speech_adaptation.ListCustomClassesRequest],
        Union[
            cloud_speech_adaptation.ListCustomClassesResponse,
            Awaitable[cloud_speech_adaptation.ListCustomClassesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def update_custom_class(
        self,
    ) -> Callable[
        [cloud_speech_adaptation.UpdateCustomClassRequest],
        Union[resource.CustomClass, Awaitable[resource.CustomClass]],
    ]:
        raise NotImplementedError()

    @property
    def delete_custom_class(
        self,
    ) -> Callable[
        [cloud_speech_adaptation.DeleteCustomClassRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()


__all__ = ("AdaptationTransport",)
